@@ -1158,6 +1158,9 @@ class SchemaNode(object):
       ``''`` (the empty string).  The description is used by
       higher-level systems (not by Colander itself).
 
+    - ``widget``: The 'widget' for this node.  Defaults to ``None``.
+      The widget attribute is not interpreted by Colander itself, it
+      is only meaningful to higher-level systems such as Deform.
     """
     
     _counter = itertools.count()
@@ -1175,10 +1178,15 @@ class SchemaNode(object):
         self.name = kw.pop('name', '')
         self.title = kw.pop('title', self.name.capitalize())
         self.description = kw.pop('description', '')
+        self.widget = kw.pop('widget', None)
         if kw:
             raise TypeError('Unknown keyword arguments: %s' % repr(kw))
         self.children = list(children)
 
+    def __iter__(self):
+        """ Iterate over the children nodes of this schema node """
+        return iter(self.children)
+
     def __repr__(self):
         return '<%s.%s object at %d (named %s)>' % (
             self.__module__,
@@ -1190,8 +1198,7 @@ class SchemaNode(object):
     @property
     def required(self):
         """ A property which returns ``True`` if the ``missing`` value
-        related to this node is the :attr:`colander.null` sentinel
-        value.
+        related to this node was not specified.
 
         A return value of ``True`` implies that a ``missing`` value
         wasn't specified for this node.  A return value of ``False``
